@@ -2,13 +2,15 @@ import psutil
 import socket
 import os
 import subprocess
+import shutil
 import distro
 import requests
 import json
+import time
 from termcolor import colored
 from cardsec.port_scanner import scan_ports
 from simple_term_menu import TerminalMenu, main
-from cardsec.utils import parser
+from cardsec.utils import parser, conf
 
 GOOD=50
 OK=75
@@ -18,7 +20,7 @@ try:
 	from importlib.metadata import version 
 	VERSION = version('cardsec')
 except: 
-	VERSION = "Not found."
+	VERSION = False
 
 
 def num_colour(num:int):
@@ -42,10 +44,10 @@ def banner():
 	print(colored("         ██║  ██╗██╔══██║██╔══██╗██║  ██║ ╚═══██╗██╔══╝  ██║  ██╗        ", "white"))
 	print(colored("         ╚█████╔╝██║  ██║██║  ██║██████╔╝██████╔╝███████╗╚█████╔╝        ", "white"))
 	print(colored("          ╚════╝ ╚═╝  ╚═╝╚═╝  ╚═╝╚═════╝ ╚═════╝ ╚══════╝ ╚════╝        ", "white"))
-	if LATEST != VERSION:
+	if VERSION and LATEST >= VERSION:
 		print(colored(f"                               version {VERSION}        ", "yellow"))
 		print(colored(f"     		        New update {LATEST} available", "red"))
-	else:
+	elif VERSION:
 		print(colored(f"                               version {VERSION}        ", "green"))
 	print("                                                                      ")
 	print(colored("                        Developed by: SkryptLabs                              ", "blue"))
@@ -54,9 +56,14 @@ def banner():
 
 
 def setup():
+	try:
+		subprocess.check_output(['cardano-node','version']).decode()
+	except:
+		print('Cardano Node not installed.')
+		print('Skipping setup...')
+		return 1
+	
 	print(colored("\n-------Setup---------\n", "magenta"))
-	with open("cardsec/conf.json", "r") as f:
-		conf = json.load(f)
 	print("Is this a relay node?")
 	menu1 = TerminalMenu(["[1] Yes", "[2] No"])
 	menu1_choice = menu1.show()
@@ -70,35 +77,49 @@ def setup():
 			conf["network"] = "mainnet"
 		elif menu2_choice == 1:
 			conf["network"] = "testnet"
-		with open("/etc/cardsec.conf", "w") as f:
+		with open("/tmp/cardsec.conf", "w") as f:
 			json.dump(conf, f)
+		run_cmd('sudo cp /tmp/cardsec.conf /etc/cardsec.conf')
 		print("\nSetup complete!\n")
 		return 0
 		
 	elif menu1_choice == 1:
 		conf["relay"] = "false"
-		with open("/etc/cardsec.conf", "w") as f:
+		with open("/tmp/cardsec.conf", "w") as f:
 			json.dump(conf, f)
+		run_cmd('sudo cp /tmp/cardsec.conf /etc/cardsec.conf')
 		print("\nSetup complete!\n")
 		return 1
 		
-	
-		
 
+def system():
+	menu_options = ["[1] System Info", "[2] System Load", "[3] Back"]
+	terminal_menu = TerminalMenu(menu_options, title="System")
+	option = terminal_menu.show()
+
+	if option == 0:
+		info()
+	elif option == 1:
+		load()
+	elif option == 2:
+		back()
+		return 1
 
 def info():
 	try:
 		node=subprocess.check_output(['cardano-node','version']).decode().split()[1]
-	except: node="Not found."
+	except: node="Not installed."
 
 	print(colored("\n-------System Info---------", "magenta"))
 
 	print("Distro: "+distro.id()+' '+distro.version())
 	print("RAM Size: " +str(psutil.virtual_memory()[0]/1024/1024//1024)+' GB')
 	print("Disk Size: " +str(psutil.disk_usage('/')[0]/1024/1024//1024)+'GB'+'\n')
-	print("Cardano-Node: " +node)
-	latest=requests.get("https://api.github.com/repos/input-output-hk/cardano-node/releases/latest").json()["tag_name"]
-	if latest == node:
+	print("Cardano-Node: " + node)
+	latest = requests.get(
+		"https://api.github.com/repos/input-output-hk/cardano-node/releases/latest"
+		).json()["tag_name"]
+	if latest <= node and node != "Not installed.":
 		print(colored("Cardano-Node is up to date", "green"))
 	else:
 		print(colored(f"Cardano-Node {latest} update available ", "red"))
@@ -125,10 +146,18 @@ def nmapscan():
 	
 	target = socket.gethostname()
 	t_IP = socket.gethostbyname(target)
+	
+	try:
+		nmap_v = subprocess.check_output(['nmap','--version']).decode().split()[2]
+		print(colored("Nmap version: "+nmap_v, "green"))
+	except:
+		#run_cmd("sudo apt-get install nmap -y")
+		print(colored("Nmap not installed.", "red"))
+		print('You will need Nmap to use this feature.\n')
+		return 1
 	print(colored("Installing vulnerability scanning scripts....", "yellow"))
-	run_cmd("sudo apt-get install nmap -y")
 	if not os.path.exists("vulners.nse"):
-		run_cmd("wget https://raw.githubusercontent.com/vulnersCom/nmap-vulners/master/vulners.nse > /dev/null 2>&1")
+		run_cmd("sudo wget https://raw.githubusercontent.com/vulnersCom/nmap-vulners/master/vulners.nse > /dev/null 2>&1")
 		run_cmd("sudo cp vulners.nse /usr/share/nmap/scripts/")
 		print("Installed Succesfully")
 	print(colored("Scanning in process, please have patience.", "yellow"))
@@ -180,11 +209,50 @@ def scan():
 			scanner(port_range)
 
 		elif suboption == 2:
-			os.system("clear")
-			banner()
-			break		
+			back()
+			return 1		
 		
 
+def installer():
+	print(colored('Experimental Feature',"red"))
+	print("Use with with caution.\n")
+	menu_options = ["[1] Cardano-node", "[2] Back"]
+	print(colored("-------One-Click Installer---------\n", "magenta"))
+	terminal_menu = TerminalMenu(menu_options)
+	option = terminal_menu.show()
+
+	if option == 0:
+		print(colored("Installing Cardano-node...", "yellow"))
+		try:
+			subprocess.check_output(['cardano-node','version']).decode()
+			path = shutil.which("cardano-node")[:-13]
+			run_cmd(f"cd {path}")
+		except:
+			path = "/usr/local/bin"
+			print(colored("No existing version found...", "yellow"))
+		print(colored("Downloading Cardano-node...", "yellow"))
+		download = subprocess.Popen(
+			"sudo wget https://hydra.iohk.io/job/Cardano/cardano-node/cardano-node-linux/latest-finished/download --output-document latest-node.tar.xf",
+			shell = True,
+			cwd = path
+			)
+		download.wait()
+		unzip = subprocess.Popen(
+			"sudo tar -xf latest-node.tar.xf && sudo rm latest-node.tar.xf",
+			shell = True,
+			cwd = path
+			)
+		unzip.wait()
+		print(colored("Cardano-node is now installed\n", "yellow"))
+		run_cmd("cardano-node version")
+	elif option == 1:
+		back()
+		return 1
+
+def back():
+	os.system("clear")
+	banner()
+
 def quit():
 	os.system("clear")
 	print("Happy Minting!")
@@ -193,8 +261,8 @@ def quit():
 
 def menu():
 	menu_options=[
-		"[1] System Info", "[2] System Load", "[3] Port Scanner", 
-		"[4] Vulnerability Scanner", "[5] Setup","[6] Exit"
+		"[1] System", "[2] Port Scanner", "[3] Vulnerability Scanner", 
+		"[4] One-Click Installer", "[5] Setup", "[6] Exit"
 		]
 	terminal_menu = TerminalMenu(menu_options, title="Home")
 	return terminal_menu.show()
@@ -202,7 +270,7 @@ def menu():
 
 def select(option):
 
-	menu_func = [info, load, scan, nmapscan, setup, quit]
+	menu_func = [system, scan, nmapscan, installer, setup, quit]
 
 	print()
 	return menu_func[option]()
@@ -214,6 +282,9 @@ def main():
 	banner()
 	if not os.path.exists("/etc/cardsec.conf"):
 		setup()
+		time.sleep(2)
+		os.system("clear")
+		banner()
 
 	while 1:
 		option = menu()
